# -*- perl -*-

use Test::More;
eval "use Test::Pod::Coverage 1.00";
plan skip_all => "Test::Pod::Coverage 1.00 required for testing POD coverage" if $@;
all_pod_coverage_ok({
     also_private => [
       'init',
       'keyword',
       'option',
       'option_mail_size',
       'parameter',
       'reply',
       'reply_mail_body',
       'reply_mail_from'
     ]
     });
